pub struct IPAllocationPolicy {
pub cluster_ipv4_cidr_block: Option<String>,
pub cluster_secondary_range_name: Option<String>,
pub services_ipv4_cidr_block: Option<String>,
pub services_secondary_range_name: Option<String>,
pub use_ip_aliases: Option<bool>,
}Expand description
Configuration for controlling how IPs are allocated in the GKE cluster running the Apache Airflow software.
This type is not used in any activity, and only used as part of another schema.
Fields
cluster_ipv4_cidr_block: Option<String>Optional. The IP address range used to allocate IP addresses to pods in the GKE cluster. For Cloud Composer environments in versions composer-1..-airflow-..*, this field is applicable only when use_ip_aliases is true. Set to blank to have GKE choose a range with the default size. Set to /netmask (e.g. /14) to have GKE choose a range with a specific netmask. Set to a CIDR notation (e.g. 10.96.0.0/14) from the RFC-1918 private networks (e.g. 10.0.0.0/8, 172.16.0.0/12, 192.168.0.0/16) to pick a specific range to use.
cluster_secondary_range_name: Option<String>Optional. The name of the GKE cluster’s secondary range used to allocate IP addresses to pods. For Cloud Composer environments in versions composer-1..-airflow-..*, this field is applicable only when use_ip_aliases is true.
services_ipv4_cidr_block: Option<String>Optional. The IP address range of the services IP addresses in this GKE cluster. For Cloud Composer environments in versions composer-1..-airflow-..*, this field is applicable only when use_ip_aliases is true. Set to blank to have GKE choose a range with the default size. Set to /netmask (e.g. /14) to have GKE choose a range with a specific netmask. Set to a CIDR notation (e.g. 10.96.0.0/14) from the RFC-1918 private networks (e.g. 10.0.0.0/8, 172.16.0.0/12, 192.168.0.0/16) to pick a specific range to use.
services_secondary_range_name: Option<String>Optional. The name of the services’ secondary range used to allocate IP addresses to the GKE cluster. For Cloud Composer environments in versions composer-1..-airflow-..*, this field is applicable only when use_ip_aliases is true.
use_ip_aliases: Option<bool>Optional. Whether or not to enable Alias IPs in the GKE cluster. If true, a VPC-native cluster is created. This field is only supported for Cloud Composer environments in versions composer-1..-airflow-..*. Environments in newer versions always use VPC-native GKE clusters.