pub struct ListWorkloadsResponse {
pub next_page_token: Option<String>,
pub workloads: Option<Vec<ComposerWorkload>>,
}Expand description
Response to ListWorkloadsRequest.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
next_page_token: Option<String>The page token used to query for the next page if one exists.
workloads: Option<Vec<ComposerWorkload>>The list of environment workloads.