pub struct PrivateEnvironmentConfig {
pub cloud_composer_connection_subnetwork: Option<String>,
pub cloud_composer_network_ipv4_cidr_block: Option<String>,
pub cloud_composer_network_ipv4_reserved_range: Option<String>,
pub cloud_sql_ipv4_cidr_block: Option<String>,
pub enable_private_builds_only: Option<bool>,
pub enable_private_environment: Option<bool>,
pub enable_privately_used_public_ips: Option<bool>,
pub networking_config: Option<NetworkingConfig>,
pub private_cluster_config: Option<PrivateClusterConfig>,
pub web_server_ipv4_cidr_block: Option<String>,
pub web_server_ipv4_reserved_range: Option<String>,
}Expand description
The configuration information for configuring a Private IP Cloud Composer environment.
This type is not used in any activity, and only used as part of another schema.
Fields
cloud_composer_connection_subnetwork: Option<String>Optional. When specified, the environment will use Private Service Connect instead of VPC peerings to connect to Cloud SQL in the Tenant Project, and the PSC endpoint in the Customer Project will use an IP address from this subnetwork.
cloud_composer_network_ipv4_cidr_block: Option<String>Optional. The CIDR block from which IP range for Cloud Composer Network in tenant project will be reserved. Needs to be disjoint from private_cluster_config.master_ipv4_cidr_block and cloud_sql_ipv4_cidr_block. This field is supported for Cloud Composer environments in versions composer-2..-airflow-..* and newer.
cloud_composer_network_ipv4_reserved_range: Option<String>Output only. The IP range reserved for the tenant project’s Cloud Composer network. This field is supported for Cloud Composer environments in versions composer-2..-airflow-..* and newer.
cloud_sql_ipv4_cidr_block: Option<String>Optional. The CIDR block from which IP range in tenant project will be reserved for Cloud SQL. Needs to be disjoint from web_server_ipv4_cidr_block.
enable_private_builds_only: Option<bool>Optional. If true, builds performed during operations that install Python packages have only private connectivity to Google services (including Artifact Registry) and VPC network (if either NodeConfig.network and NodeConfig.subnetwork fields or NodeConfig.composer_network_attachment field are specified). If false, the builds also have access to the internet. This field is supported for Cloud Composer environments in versions composer-3-airflow-..-build. and newer.
enable_private_environment: Option<bool>Optional. If true, a Private IP Cloud Composer environment is created. If this field is set to true, IPAllocationPolicy.use_ip_aliases must be set to true for Cloud Composer environments in versions composer-1..-airflow-..*.
enable_privately_used_public_ips: Option<bool>Optional. When enabled, IPs from public (non-RFC1918) ranges can be used for IPAllocationPolicy.cluster_ipv4_cidr_block and IPAllocationPolicy.service_ipv4_cidr_block.
networking_config: Option<NetworkingConfig>Optional. Configuration for the network connections configuration in the environment.
private_cluster_config: Option<PrivateClusterConfig>Optional. Configuration for the private GKE cluster for a Private IP Cloud Composer environment.
web_server_ipv4_cidr_block: Option<String>Optional. The CIDR block from which IP range for web server will be reserved. Needs to be disjoint from private_cluster_config.master_ipv4_cidr_block and cloud_sql_ipv4_cidr_block. This field is supported for Cloud Composer environments in versions composer-1..-airflow-..*.
web_server_ipv4_reserved_range: Option<String>Output only. The IP range reserved for the tenant project’s App Engine VMs. This field is supported for Cloud Composer environments in versions composer-1..-airflow-..*.