pub struct UserWorkloadsSecret {
pub data: Option<HashMap<String, String>>,
pub name: Option<String>,
}Expand description
User workloads Secret used by Airflow tasks that run with Kubernetes executor or KubernetesPodOperator.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations environments user workloads secrets create projects (request|response)
- locations environments user workloads secrets get projects (response)
- locations environments user workloads secrets update projects (request|response)
Fields
data: Option<HashMap<String, String>>Optional. The “data” field of Kubernetes Secret, organized in key-value pairs, which can contain sensitive values such as a password, a token, or a key. The values for all keys have to be base64-encoded strings. For details see: https://kubernetes.io/docs/concepts/configuration/secret/ Example: { “example”: “ZXhhbXBsZV92YWx1ZQ==”, “another-example”: “YW5vdGhlcl9leGFtcGxlX3ZhbHVl” }
name: Option<String>Identifier. The resource name of the Secret, in the form: “projects/{projectId}/locations/{locationId}/environments/{environmentId}/userWorkloadsSecrets/{userWorkloadsSecretId}”